@@ -1,23 +1,5 @@
 var NAVTREEINDEX34 =
 {
-"classgr_1_1qtgui_1_1eye__sink__f.html#ad0a17ef061f38d8e0adee502343d0a08":[6,0,2,13,4,18],
-"classgr_1_1qtgui_1_1eye__sink__f.html#ad62618fe9637b7c701c88865699ef7a0":[5,0,2,16,4,36],
-"classgr_1_1qtgui_1_1eye__sink__f.html#ad62618fe9637b7c701c88865699ef7a0":[6,0,2,13,4,36],
-"classgr_1_1qtgui_1_1eye__sink__f.html#ad71182223c3c32c851e168283c00847d":[5,0,2,16,4,38],
-"classgr_1_1qtgui_1_1eye__sink__f.html#ad71182223c3c32c851e168283c00847d":[6,0,2,13,4,38],
-"classgr_1_1qtgui_1_1eye__sink__f.html#ad866ec585fcada5c64cc15d511c11555":[5,0,2,16,4,35],
-"classgr_1_1qtgui_1_1eye__sink__f.html#ad866ec585fcada5c64cc15d511c11555":[6,0,2,13,4,35],
-"classgr_1_1qtgui_1_1eye__sink__f.html#adc61c0c142cea30274efa3d62379de93":[5,0,2,16,4,2],
-"classgr_1_1qtgui_1_1eye__sink__f.html#adc61c0c142cea30274efa3d62379de93":[6,0,2,13,4,2],
-"classgr_1_1qtgui_1_1eye__sink__f.html#ade266d37949936da110bef4ce0479e36":[5,0,2,16,4,16],
-"classgr_1_1qtgui_1_1eye__sink__f.html#ade266d37949936da110bef4ce0479e36":[6,0,2,13,4,16],
-"classgr_1_1qtgui_1_1eye__sink__f.html#ae2744237ee7c4580831edd92c6bfcf71":[5,0,2,16,4,9],
-"classgr_1_1qtgui_1_1eye__sink__f.html#ae2744237ee7c4580831edd92c6bfcf71":[6,0,2,13,4,9],
-"classgr_1_1qtgui_1_1eye__sink__f.html#aec2074a3a1bd276b580f73a0c0f4d55f":[5,0,2,16,4,23],
-"classgr_1_1qtgui_1_1eye__sink__f.html#aec2074a3a1bd276b580f73a0c0f4d55f":[6,0,2,13,4,23],
-"classgr_1_1qtgui_1_1eye__sink__f.html#af6f7a7839319e137d31ffa169b4be50a":[5,0,2,16,4,27],
-"classgr_1_1qtgui_1_1eye__sink__f.html#af6f7a7839319e137d31ffa169b4be50a":[6,0,2,13,4,27],
-"classgr_1_1qtgui_1_1freq__sink__c.html":[4,0,15,1],
 "classgr_1_1qtgui_1_1freq__sink__c.html":[4,0,27,9],
 "classgr_1_1qtgui_1_1freq__sink__c.html#a0187a0131152e4d60e71659079c44f51":[4,0,15,1,0],
 "classgr_1_1qtgui_1_1freq__sink__c.html#a0187a0131152e4d60e71659079c44f51":[4,0,27,9,0],
@@ -249,5 +231,23 @@ var NAVTREEINDEX34 =
 "classgr_1_1qtgui_1_1histogram__sink__f.html#ac64899a818349d1df1f8c29da3bf5ca6":[4,0,27,13,33],
 "classgr_1_1qtgui_1_1histogram__sink__f.html#aceb30a258ee426630b3e8556d53975c7":[4,0,15,3,29],
 "classgr_1_1qtgui_1_1histogram__sink__f.html#aceb30a258ee426630b3e8556d53975c7":[4,0,27,13,29],
-"classgr_1_1qtgui_1_1histogram__sink__f.html#ad73087a5d4587d1f0f1524e3df7e406f":[4,0,15,3,19]
+"classgr_1_1qtgui_1_1histogram__sink__f.html#ad73087a5d4587d1f0f1524e3df7e406f":[4,0,15,3,19],
+"classgr_1_1qtgui_1_1histogram__sink__f.html#ad73087a5d4587d1f0f1524e3df7e406f":[4,0,27,13,19],
+"classgr_1_1qtgui_1_1histogram__sink__f.html#ad939536338de8d036182f345e7b5cd8c":[4,0,15,3,10],
+"classgr_1_1qtgui_1_1histogram__sink__f.html#ad939536338de8d036182f345e7b5cd8c":[4,0,27,13,10],
+"classgr_1_1qtgui_1_1histogram__sink__f.html#adac4cb4318482aa3eb72607d51fc4ae0":[4,0,15,3,22],
+"classgr_1_1qtgui_1_1histogram__sink__f.html#adac4cb4318482aa3eb72607d51fc4ae0":[4,0,27,13,22],
+"classgr_1_1qtgui_1_1histogram__sink__f.html#ade9ce482619e0c5c55b8303596fb48cf":[4,0,15,3,18],
+"classgr_1_1qtgui_1_1histogram__sink__f.html#ade9ce482619e0c5c55b8303596fb48cf":[4,0,27,13,18],
+"classgr_1_1qtgui_1_1histogram__sink__f.html#ae0045cd1fae6c1b527e92524c99efb6a":[4,0,15,3,24],
+"classgr_1_1qtgui_1_1histogram__sink__f.html#ae0045cd1fae6c1b527e92524c99efb6a":[4,0,27,13,24],
+"classgr_1_1qtgui_1_1histogram__sink__f.html#aec3dff0c66633a2f730639d60eaf1123":[4,0,15,3,7],
+"classgr_1_1qtgui_1_1histogram__sink__f.html#aec3dff0c66633a2f730639d60eaf1123":[4,0,27,13,7],
+"classgr_1_1qtgui_1_1histogram__sink__f.html#af08d3f6216837108efdf657f020dccc9":[4,0,15,3,15],
+"classgr_1_1qtgui_1_1histogram__sink__f.html#af08d3f6216837108efdf657f020dccc9":[4,0,27,13,15],
+"classgr_1_1qtgui_1_1histogram__sink__f.html#af377b448882075e0a19535b6c5684c6d":[4,0,15,3,2],
+"classgr_1_1qtgui_1_1histogram__sink__f.html#af377b448882075e0a19535b6c5684c6d":[4,0,27,13,2],
+"classgr_1_1qtgui_1_1histogram__sink__f.html#af83ee310e63e59a054dca6828e96bc10":[4,0,15,3,30],
+"classgr_1_1qtgui_1_1histogram__sink__f.html#af83ee310e63e59a054dca6828e96bc10":[4,0,27,13,30],
+"classgr_1_1qtgui_1_1histogram__sink__f.html#af9c42348178bb37d9d2716b77fa431ce":[4,0,15,3,31]
 };
