@@ -1,69 +1,5 @@
 var NAVTREEINDEX54 =
 {
-"generic__encoder__pydoc__template_8h.html#af18094c36adcc0bfc2830ddb2349d9fd":[7,0,17,2,0,0,0,16,9],
-"generic__encoder__pydoc__template_8h.html#af3a57fef3e1fca34a97f398770664bd6":[7,0,17,2,0,0,0,16,11],
-"generic__encoder__pydoc__template_8h_source.html":[7,0,17,2,0,0,0,16],
-"gf2mat_8h.html":[7,0,17,1,0,0,22],
-"gf2mat_8h_source.html":[7,0,17,1,0,0,22],
-"gf2vec_8h.html":[7,0,17,1,0,0,23],
-"gf2vec_8h_source.html":[7,0,17,1,0,0,23],
-"glfsr_8h.html":[7,0,13,1,0,0,39],
-"glfsr_8h_source.html":[7,0,13,1,0,0,39],
-"glfsr__pydoc__template_8h.html":[7,0,13,2,0,0,0,37],
-"glfsr__pydoc__template_8h.html#a0f090482bf9ba961be659696dc9fe04d":[7,0,13,2,0,0,0,37,6],
-"glfsr__pydoc__template_8h.html#a1742ce1a5a575b925284061311a2cdd5":[7,0,13,2,0,0,0,37,2],
-"glfsr__pydoc__template_8h.html#a19eaa7f9e598210ba9538612fa6e2a6e":[7,0,13,2,0,0,0,37,4],
-"glfsr__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,13,2,0,0,0,37,0],
-"glfsr__pydoc__template_8h.html#a899f6d7f584a0df1607b66faeb3d88b2":[7,0,13,2,0,0,0,37,3],
-"glfsr__pydoc__template_8h.html#ab45de69ad7e21402a99e6dec8107e703":[7,0,13,2,0,0,0,37,1],
-"glfsr__pydoc__template_8h.html#ab5ad96ebdc9b184386ccdbc5c3c30b24":[7,0,13,2,0,0,0,37,5],
-"glfsr__pydoc__template_8h_source.html":[7,0,13,2,0,0,0,37],
-"glfsr__source__b_8h.html":[7,0,13,1,0,0,40],
-"glfsr__source__b_8h_source.html":[7,0,13,1,0,0,40],
-"glfsr__source__b__pydoc__template_8h.html":[7,0,13,2,0,0,0,38],
-"glfsr__source__b__pydoc__template_8h.html#a1cb431fe6466137fa10a3e321c346d8c":[7,0,13,2,0,0,0,38,2],
-"glfsr__source__b__pydoc__template_8h.html#a6ee47ebda072a8c92cd22ba5bba8f8a5":[7,0,13,2,0,0,0,38,3],
-"glfsr__source__b__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,13,2,0,0,0,38,0],
-"glfsr__source__b__pydoc__template_8h.html#a7db4893732d3e6b83f8878a8492c4980":[7,0,13,2,0,0,0,38,4],
-"glfsr__source__b__pydoc__template_8h.html#ac6e2a4d6deca9e145c5bbb3496c702c8":[7,0,13,2,0,0,0,38,1],
-"glfsr__source__b__pydoc__template_8h.html#af4cac8194cc8dd0a00ff9c08bf9bb56a":[7,0,13,2,0,0,0,38,5],
-"glfsr__source__b__pydoc__template_8h.html#afb463796fff6f988c53e18db126a51de":[7,0,13,2,0,0,0,38,6],
-"glfsr__source__b__pydoc__template_8h_source.html":[7,0,13,2,0,0,0,38],
-"glfsr__source__f_8h.html":[7,0,13,1,0,0,41],
-"glfsr__source__f_8h_source.html":[7,0,13,1,0,0,41],
-"glfsr__source__f__pydoc__template_8h.html":[7,0,13,2,0,0,0,39],
-"glfsr__source__f__pydoc__template_8h.html#a094c7382b78d224ba592ea084ce8ca19":[7,0,13,2,0,0,0,39,2],
-"glfsr__source__f__pydoc__template_8h.html#a4188acd09819c3f8b5ef9324c92d4cdf":[7,0,13,2,0,0,0,39,4],
-"glfsr__source__f__pydoc__template_8h.html#a6e8b2f343fe7baddf61f47e422c4f146":[7,0,13,2,0,0,0,39,5],
-"glfsr__source__f__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,13,2,0,0,0,39,0],
-"glfsr__source__f__pydoc__template_8h.html#a7d677e0aae0f1edb11a6c012ffcbe55b":[7,0,13,2,0,0,0,39,1],
-"glfsr__source__f__pydoc__template_8h.html#aa98f2181bde9f1068aaaa8b1f2f83de6":[7,0,13,2,0,0,0,39,3],
-"glfsr__source__f__pydoc__template_8h.html#afef332e206222c2ad0a6add8a4e9e2c9":[7,0,13,2,0,0,0,39,6],
-"glfsr__source__f__pydoc__template_8h_source.html":[7,0,13,2,0,0,0,39],
-"globals.html":[7,1,0],
-"globals.html":[7,1,0,0],
-"globals_a.html":[7,1,0,1],
-"globals_b.html":[7,1,0,2],
-"globals_c.html":[7,1,0,3],
-"globals_d.html":[7,1,0,4],
-"globals_defs.html":[7,1,6],
-"globals_defs.html":[7,1,6,0],
-"globals_defs_a.html":[7,1,6,1],
-"globals_defs_b.html":[7,1,6,2],
-"globals_defs_c.html":[7,1,6,3],
-"globals_defs_d.html":[7,1,6,4],
-"globals_defs_f.html":[7,1,6,5],
-"globals_defs_g.html":[7,1,6,6],
-"globals_defs_i.html":[7,1,6,7],
-"globals_defs_m.html":[7,1,6,8],
-"globals_defs_n.html":[7,1,6,9],
-"globals_defs_p.html":[7,1,6,10],
-"globals_defs_q.html":[7,1,6,11],
-"globals_defs_s.html":[7,1,6,12],
-"globals_defs_t.html":[7,1,6,13],
-"globals_defs_v.html":[7,1,6,14],
-"globals_defs_w.html":[7,1,6,15],
-"globals_defs_z.html":[7,1,6,16],
 "globals_e.html":[7,1,0,5],
 "globals_enum.html":[7,1,4],
 "globals_eval.html":[7,1,5],
@@ -249,5 +185,69 @@ var NAVTREEINDEX54 =
 "gr__complex_8h_source.html":[7,0,3,0,0,23],
 "group__applications.html":[4,4],
 "group__audio__blk.html":[4,0,1],
-"group__base__blk.html":[4,0,38]
+"group__base__blk.html":[4,0,38],
+"group__block.html":[4,0],
+"group__boolean__operators__blk.html":[4,0,2],
+"group__byte__operators__blk.html":[4,0,3],
+"group__channel__models__blk.html":[4,0,4],
+"group__channelizers__blk.html":[4,0,5],
+"group__coding__blk.html":[4,0,6],
+"group__container__blk.html":[4,0,0],
+"group__controlport__blk.html":[4,0,7],
+"group__debug__tools__blk.html":[4,0,8],
+"group__deprecated__blk.html":[4,0,9],
+"group__equalizers__blk.html":[4,0,10],
+"group__error__coding__blk.html":[4,0,11],
+"group__file__operators__blk.html":[4,0,12],
+"group__filter__blk.html":[4,0,13],
+"group__filter__design.html":[4,1],
+"group__filter__design.html#gaeb926a91ce5acb128e6c348a782b47dc":[4,1,1],
+"group__fourier__analysis__blk.html":[4,0,14],
+"group__hardware.html":[4,5],
+"group__instrumentation__blk.html":[4,0,15],
+"group__internal.html":[4,3],
+"group__internal.html#ga524c1d5413cf1d28ebb97656057d622f":[4,3,9],
+"group__internal.html#gae8ff9ba44dadc54d5f03ec25e3efb4ae":[4,3,8],
+"group__level__controllers__blk.html":[4,0,16],
+"group__math__operators__blk.html":[4,0,17],
+"group__measurement__tools__blk.html":[4,0,18],
+"group__measurement__tools__blk.html#ga56518da55fdaa3723f89e20f2db2ca12":[4,0,18,19],
+"group__measurement__tools__blk.html#gga56518da55fdaa3723f89e20f2db2ca12a204d2b2cfc4aaf860fe56445aff6432f":[4,0,18,19,0],
+"group__measurement__tools__blk.html#gga56518da55fdaa3723f89e20f2db2ca12a5f20dc2162ef6c3f695caaeb68f559ff":[4,0,18,19,2],
+"group__measurement__tools__blk.html#gga56518da55fdaa3723f89e20f2db2ca12ad3a7d8318e8262c56142601d9aa34b3e":[4,0,18,19,3],
+"group__measurement__tools__blk.html#gga56518da55fdaa3723f89e20f2db2ca12afacbe50e9ca04aa6feb581b71e65152d":[4,0,18,19,1],
+"group__message__tools__blk.html":[4,0,19],
+"group__misc.html":[4,2],
+"group__misc.html#ga247b4ca5ffc9ec61f82c5c455fbcb755":[4,2,13],
+"group__misc.html#ga6c1470346a3524989b7a8a3639aa79a7":[4,2,14],
+"group__misc__blk.html":[4,0,20],
+"group__modulators__blk.html":[4,0,21],
+"group__networking__tools__blk.html":[4,0,22],
+"group__ofdm__blk.html":[4,0,23],
+"group__packet__operators__blk.html":[4,0,24],
+"group__pdu__blk.html":[4,0,26],
+"group__peak__detectors__blk.html":[4,0,25],
+"group__qtgui__blk.html":[4,0,27],
+"group__resamplers__blk.html":[4,0,28],
+"group__stream__operators__blk.html":[4,0,29],
+"group__stream__tag__tools__blk.html":[4,0,30],
+"group__symbol__coding__blk.html":[4,0,31],
+"group__synchronizers__blk.html":[4,0,32],
+"group__synchronizers__blk.html#gac1749266339e589356ef04459650a277":[4,0,32,15],
+"group__synchronizers__blk.html#ggac1749266339e589356ef04459650a277a4970f00fc463af6db76ac33154657439":[4,0,32,15,1],
+"group__synchronizers__blk.html#ggac1749266339e589356ef04459650a277a4aa0799f0869ae6ded6a31e58f5729c1":[4,0,32,15,0],
+"group__trellis__coding__blk.html":[4,0,33],
+"group__type__converters__blk.html":[4,0,34],
+"group__uhd__blk.html":[4,0,35],
+"group__uhd__blk.html#gacf4de92d23244606851818761c53d228":[4,0,35,13],
+"group__waveform__generators__blk.html":[4,0,36],
+"group__waveform__generators__blk.html#gac97c0f42ffb63f1265decceaaeab9177":[4,0,36,8],
+"group__waveform__generators__blk.html#ggac97c0f42ffb63f1265decceaaeab9177a08852de05c21a6ffa08f5fd568f6c4e8":[4,0,36,8,5],
+"group__waveform__generators__blk.html#ggac97c0f42ffb63f1265decceaaeab9177a17daa0284adc5ccdd7c6551c5cc3c962":[4,0,36,8,4],
+"group__waveform__generators__blk.html#ggac97c0f42ffb63f1265decceaaeab9177a3ef7631b8292bb9bea1603241bb91951":[4,0,36,8,2],
+"group__waveform__generators__blk.html#ggac97c0f42ffb63f1265decceaaeab9177a71dd5e4a7046847f12d395f4d0722069":[4,0,36,8,1],
+"group__waveform__generators__blk.html#ggac97c0f42ffb63f1265decceaaeab9177ab16cf544b1512511042814e630368705":[4,0,36,8,3],
+"group__waveform__generators__blk.html#ggac97c0f42ffb63f1265decceaaeab9177ae498d246944b97c4e6e46dbe72e78710":[4,0,36,8,0],
+"group__wavelet__blk.html":[4,0,37],
+"gsm__fr__decode__ps_8h.html":[7,0,38,1,0,0,17]
 };
