@@ -1,69 +1,5 @@
 var NAVTREEINDEX56 =
 {
-"high__res__timer__pydoc__template_8h_source.html":[7,0,3,1,0,0,0,0,14],
-"hilbert__fc_8h.html":[7,0,21,1,0,0,15],
-"hilbert__fc_8h_source.html":[7,0,21,1,0,0,15],
-"hilbert__fc__pydoc__template_8h.html":[7,0,21,2,0,0,0,14],
-"hilbert__fc__pydoc__template_8h.html#a5eef26b7182c9f4632c9295d5cd11fdd":[7,0,21,2,0,0,0,14,1],
-"hilbert__fc__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,21,2,0,0,0,14,0],
-"hilbert__fc__pydoc__template_8h.html#a7a02e2ed52f8d401230a7889895730ba":[7,0,21,2,0,0,0,14,3],
-"hilbert__fc__pydoc__template_8h.html#ae2ad50fe14dfa9e9d18d2e876d26f42d":[7,0,21,2,0,0,0,14,2],
-"hilbert__fc__pydoc__template_8h_source.html":[7,0,21,2,0,0,0,14],
-"histogram__sink__f_8h.html":[7,0,29,1,0,0,20],
-"histogram__sink__f_8h_source.html":[7,0,29,1,0,0,20],
-"histogram__sink__f__pydoc__template_8h.html":[7,0,29,2,0,0,0,12],
-"histogram__sink__f__pydoc__template_8h.html#a0bef9875ce5f2368cfb4f9270c62c137":[7,0,29,2,0,0,0,12,35],
-"histogram__sink__f__pydoc__template_8h.html#a0dd0f1adf879e3b705d79bdf6f85edbb":[7,0,29,2,0,0,0,12,27],
-"histogram__sink__f__pydoc__template_8h.html#a0e787aaecc1e7f04676331114b0a2112":[7,0,29,2,0,0,0,12,31],
-"histogram__sink__f__pydoc__template_8h.html#a1cd015a2c4c7299e7c7876a21b30709c":[7,0,29,2,0,0,0,12,1],
-"histogram__sink__f__pydoc__template_8h.html#a1fcdadc33ae2224609e541196894ced9":[7,0,29,2,0,0,0,12,26],
-"histogram__sink__f__pydoc__template_8h.html#a2c8d77bbe648fbc9571234bee9c8d04c":[7,0,29,2,0,0,0,12,11],
-"histogram__sink__f__pydoc__template_8h.html#a2fd83defa4d13f3334843596b6b2edb8":[7,0,29,2,0,0,0,12,22],
-"histogram__sink__f__pydoc__template_8h.html#a2fee772708e0dd4db0712cadcf843d35":[7,0,29,2,0,0,0,12,13],
-"histogram__sink__f__pydoc__template_8h.html#a379773b82070cc274cdaff67d76112a1":[7,0,29,2,0,0,0,12,3],
-"histogram__sink__f__pydoc__template_8h.html#a3934601e609b77491f2a7029fe1a066a":[7,0,29,2,0,0,0,12,18],
-"histogram__sink__f__pydoc__template_8h.html#a3a37139b978bbd6c30322765194c8dce":[7,0,29,2,0,0,0,12,33],
-"histogram__sink__f__pydoc__template_8h.html#a3d44092cae83db8dffa8f839ca0b2475":[7,0,29,2,0,0,0,12,28],
-"histogram__sink__f__pydoc__template_8h.html#a3e25e981d42b2345b33dd80459d57801":[7,0,29,2,0,0,0,12,10],
-"histogram__sink__f__pydoc__template_8h.html#a48332eb0b7c1ee67900f4163667cfa88":[7,0,29,2,0,0,0,12,20],
-"histogram__sink__f__pydoc__template_8h.html#a4cc036d84bfa83a5442bd715c976eb31":[7,0,29,2,0,0,0,12,24],
-"histogram__sink__f__pydoc__template_8h.html#a4f8075785c8c9e4680b147a5ebd16392":[7,0,29,2,0,0,0,12,15],
-"histogram__sink__f__pydoc__template_8h.html#a58ae13077653def21f37a2f39b4290d0":[7,0,29,2,0,0,0,12,2],
-"histogram__sink__f__pydoc__template_8h.html#a60c6ec75443fb0049dbf221f71cfb1e4":[7,0,29,2,0,0,0,12,21],
-"histogram__sink__f__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,29,2,0,0,0,12,0],
-"histogram__sink__f__pydoc__template_8h.html#a83151ba1d446b185e284cc8c20f04f64":[7,0,29,2,0,0,0,12,34],
-"histogram__sink__f__pydoc__template_8h.html#a858a95d397f601b7d77a2e2b4acdcd54":[7,0,29,2,0,0,0,12,8],
-"histogram__sink__f__pydoc__template_8h.html#a8acaec9888f6ad12af8fd74241b5ae32":[7,0,29,2,0,0,0,12,25],
-"histogram__sink__f__pydoc__template_8h.html#a926e32f67bbaa7d73c5e87b474b936de":[7,0,29,2,0,0,0,12,30],
-"histogram__sink__f__pydoc__template_8h.html#a9319ae0243c1e5012abdb41b8eaa164e":[7,0,29,2,0,0,0,12,23],
-"histogram__sink__f__pydoc__template_8h.html#a93b82448093cfcd104feb25a01689c06":[7,0,29,2,0,0,0,12,17],
-"histogram__sink__f__pydoc__template_8h.html#aa5ed42313d2e9ac284f4c6ad43849562":[7,0,29,2,0,0,0,12,6],
-"histogram__sink__f__pydoc__template_8h.html#ab71924fd72f430d924e2af84be6d408e":[7,0,29,2,0,0,0,12,19],
-"histogram__sink__f__pydoc__template_8h.html#ac4f92d10f9dab9a2be066e973db71e4a":[7,0,29,2,0,0,0,12,5],
-"histogram__sink__f__pydoc__template_8h.html#ac560204f6a3f4616c3469ca37dd2c368":[7,0,29,2,0,0,0,12,32],
-"histogram__sink__f__pydoc__template_8h.html#ac78ce1ff8f403e7899cb244a576e9963":[7,0,29,2,0,0,0,12,7],
-"histogram__sink__f__pydoc__template_8h.html#ac7c5eca32a94fb74aca102de6f703ce1":[7,0,29,2,0,0,0,12,14],
-"histogram__sink__f__pydoc__template_8h.html#ad587680a23a0a4b8e2181b37e8300f02":[7,0,29,2,0,0,0,12,12],
-"histogram__sink__f__pydoc__template_8h.html#adc3948987545579ea618fedccef76d3d":[7,0,29,2,0,0,0,12,4],
-"histogram__sink__f__pydoc__template_8h.html#ae28ec10964ee087cd60440e9a4ab54a0":[7,0,29,2,0,0,0,12,36],
-"histogram__sink__f__pydoc__template_8h.html#aeacc62f8afa5344938eeabb1ba356db1":[7,0,29,2,0,0,0,12,29],
-"histogram__sink__f__pydoc__template_8h.html#af3f378073911f0fbd16ec23a8bc2aef1":[7,0,29,2,0,0,0,12,9],
-"histogram__sink__f__pydoc__template_8h.html#afb9a4be2f460c36cbd26be0d8f4849e4":[7,0,29,2,0,0,0,12,37],
-"histogram__sink__f__pydoc__template_8h.html#afbfd046f1d5ca2c98b7e2e080886382c":[7,0,29,2,0,0,0,12,38],
-"histogram__sink__f__pydoc__template_8h.html#affb204b93e07dc565594fff45ec75669":[7,0,29,2,0,0,0,12,16],
-"histogram__sink__f__pydoc__template_8h_source.html":[7,0,29,2,0,0,0,12],
-"histogramdisplayform_8h.html":[7,0,29,1,0,0,21],
-"histogramdisplayform_8h_source.html":[7,0,29,1,0,0,21],
-"histogramdisplayform__pydoc__template_8h.html":[7,0,29,2,0,0,0,13],
-"histogramdisplayform__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,29,2,0,0,0,13,0],
-"histogramdisplayform__pydoc__template_8h_source.html":[7,0,29,2,0,0,0,13],
-"host__buffer_8h.html":[7,0,3,0,0,26],
-"host__buffer_8h_source.html":[7,0,3,0,0,26],
-"host__buffer__copy_8h.html":[7,0,9,1,0,0,63],
-"host__buffer__copy_8h_source.html":[7,0,9,1,0,0,63],
-"host__buffer__copy__pydoc__template_8h.html":[7,0,9,2,0,0,0,60],
-"host__buffer__copy__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,9,2,0,0,0,60,0],
-"host__buffer__copy__pydoc__template_8h.html#ad1df204e0b01c610e1b7c472b68aaee6":[7,0,9,2,0,0,0,60,1],
 "host__buffer__copy__pydoc__template_8h.html#adf4a6cf5f48f264b1c280f0c3d8e89e9":[7,0,9,2,0,0,0,60,2],
 "host__buffer__copy__pydoc__template_8h_source.html":[7,0,9,2,0,0,0,60],
 "iio__types_8h.html":[7,0,23,0,0,0,9],
@@ -249,5 +185,69 @@ var NAVTREEINDEX56 =
 "keep__one__in__n_8h.html":[7,0,9,1,0,0,70],
 "keep__one__in__n_8h_source.html":[7,0,9,1,0,0,70],
 "keep__one__in__n__pydoc__template_8h.html":[7,0,9,2,0,0,0,67],
-"keep__one__in__n__pydoc__template_8h.html#a22bc3a08fb4ab14bc1307a6d24ddd2d1":[7,0,9,2,0,0,0,67,3]
+"keep__one__in__n__pydoc__template_8h.html#a22bc3a08fb4ab14bc1307a6d24ddd2d1":[7,0,9,2,0,0,0,67,3],
+"keep__one__in__n__pydoc__template_8h.html#a5d3710d877a0780ae05a08cc4f46f7f0":[7,0,9,2,0,0,0,67,4],
+"keep__one__in__n__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,9,2,0,0,0,67,0],
+"keep__one__in__n__pydoc__template_8h.html#ac1028b5d380e87494be9562890436b70":[7,0,9,2,0,0,0,67,2],
+"keep__one__in__n__pydoc__template_8h.html#accbf1797ded790b0d07879591fe50dd1":[7,0,9,2,0,0,0,67,5],
+"keep__one__in__n__pydoc__template_8h.html#ad67f82ab65d359e6139e6be6ff6a71b5":[7,0,9,2,0,0,0,67,1],
+"keep__one__in__n__pydoc__template_8h_source.html":[7,0,9,2,0,0,0,67],
+"ldpc__G__matrix_8h.html":[7,0,17,1,0,0,27],
+"ldpc__G__matrix_8h_source.html":[7,0,17,1,0,0,27],
+"ldpc__G__matrix__pydoc__template_8h.html":[7,0,17,2,0,0,0,20],
+"ldpc__G__matrix__pydoc__template_8h.html#a2a407e0156d810d938af44eeddd5ec27":[7,0,17,2,0,0,0,20,1],
+"ldpc__G__matrix__pydoc__template_8h.html#a2d9d0345b9ef5c3d2759505a18a6eead":[7,0,17,2,0,0,0,20,3],
+"ldpc__G__matrix__pydoc__template_8h.html#a333bbabe281eaf28b4317cca0b72cfcf":[7,0,17,2,0,0,0,20,6],
+"ldpc__G__matrix__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,17,2,0,0,0,20,0],
+"ldpc__G__matrix__pydoc__template_8h.html#a7599433af6d21c213919a4cef6cee073":[7,0,17,2,0,0,0,20,7],
+"ldpc__G__matrix__pydoc__template_8h.html#a97b4cc5483e51b359b488e0d4b06b98d":[7,0,17,2,0,0,0,20,8],
+"ldpc__G__matrix__pydoc__template_8h.html#aa69650f7c4d393160d7b4055556ea900":[7,0,17,2,0,0,0,20,5],
+"ldpc__G__matrix__pydoc__template_8h.html#ad784641361968b6a21ee45dd57af4928":[7,0,17,2,0,0,0,20,2],
+"ldpc__G__matrix__pydoc__template_8h.html#afc7208a8dbc875e19fda6fbf52a33c84":[7,0,17,2,0,0,0,20,4],
+"ldpc__G__matrix__pydoc__template_8h_source.html":[7,0,17,2,0,0,0,20],
+"ldpc__H__matrix_8h.html":[7,0,17,1,0,0,29],
+"ldpc__H__matrix_8h_source.html":[7,0,17,1,0,0,29],
+"ldpc__H__matrix__pydoc__template_8h.html":[7,0,17,2,0,0,0,22],
+"ldpc__H__matrix__pydoc__template_8h.html#a1e2d646ba6415887261906b0eace682c":[7,0,17,2,0,0,0,22,7],
+"ldpc__H__matrix__pydoc__template_8h.html#a1efee11953a0462ed950abee3c73ae48":[7,0,17,2,0,0,0,22,2],
+"ldpc__H__matrix__pydoc__template_8h.html#a4be2bece38566006ca2c55607b6fdb56":[7,0,17,2,0,0,0,22,6],
+"ldpc__H__matrix__pydoc__template_8h.html#a5b214c21b93c9948dc56030187b798fe":[7,0,17,2,0,0,0,22,8],
+"ldpc__H__matrix__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,17,2,0,0,0,22,0],
+"ldpc__H__matrix__pydoc__template_8h.html#a9456caabf679905aa4cc9bd886ad2222":[7,0,17,2,0,0,0,22,5],
+"ldpc__H__matrix__pydoc__template_8h.html#a9f125e35a90efce27f5c99cae361a569":[7,0,17,2,0,0,0,22,1],
+"ldpc__H__matrix__pydoc__template_8h.html#aedaa7fe8b723b0124a1b2770e1a05df5":[7,0,17,2,0,0,0,22,4],
+"ldpc__H__matrix__pydoc__template_8h.html#afcb17f11d9277d471713fa7a9a15fd7e":[7,0,17,2,0,0,0,22,3],
+"ldpc__H__matrix__pydoc__template_8h_source.html":[7,0,17,2,0,0,0,22],
+"ldpc__bit__flip__decoder_8h.html":[7,0,17,1,0,0,24],
+"ldpc__bit__flip__decoder_8h_source.html":[7,0,17,1,0,0,24],
+"ldpc__bit__flip__decoder__pydoc__template_8h.html":[7,0,17,2,0,0,0,17],
+"ldpc__bit__flip__decoder__pydoc__template_8h.html#a1c4f40ff525c57a2b7cccf47496b6794":[7,0,17,2,0,0,0,17,3],
+"ldpc__bit__flip__decoder__pydoc__template_8h.html#a3f66c8050f8fcd517c1b4ca98bcefd41":[7,0,17,2,0,0,0,17,1],
+"ldpc__bit__flip__decoder__pydoc__template_8h.html#a51397f3680385e8818d35ae9b4d99654":[7,0,17,2,0,0,0,17,5],
+"ldpc__bit__flip__decoder__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,17,2,0,0,0,17,0],
+"ldpc__bit__flip__decoder__pydoc__template_8h.html#a7d9dea1f7aee7239b2bb55ed64b993ad":[7,0,17,2,0,0,0,17,4],
+"ldpc__bit__flip__decoder__pydoc__template_8h.html#aaee9a31c4a8ac3e239f2dc3c4e6bf26f":[7,0,17,2,0,0,0,17,6],
+"ldpc__bit__flip__decoder__pydoc__template_8h.html#af3a8ab539f7654a30088eac417b90d77":[7,0,17,2,0,0,0,17,2],
+"ldpc__bit__flip__decoder__pydoc__template_8h_source.html":[7,0,17,2,0,0,0,17],
+"ldpc__decoder_8h.html":[7,0,17,1,0,0,25],
+"ldpc__decoder_8h.html#a3aa7c7f68a54e1f12eb7436b08a7e42c":[7,0,17,1,0,0,25,1],
+"ldpc__decoder_8h.html#a835c3ff58958208962016270902b353d":[7,0,17,1,0,0,25,2],
+"ldpc__decoder_8h.html#ac1523ae42afd8a855ad59b36c35342fe":[7,0,17,1,0,0,25,3],
+"ldpc__decoder_8h_source.html":[7,0,17,1,0,0,25],
+"ldpc__decoder__pydoc__template_8h.html":[7,0,17,2,0,0,0,18],
+"ldpc__decoder__pydoc__template_8h.html#a12fec7e011c189347e14e53d69aaa24e":[7,0,17,2,0,0,0,18,5],
+"ldpc__decoder__pydoc__template_8h.html#a24c5146b87bc5a579185626525f87de8":[7,0,17,2,0,0,0,18,10],
+"ldpc__decoder__pydoc__template_8h.html#a730257f36353169dcd88cdd92ff4d2b6":[7,0,17,2,0,0,0,18,8],
+"ldpc__decoder__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,17,2,0,0,0,18,0],
+"ldpc__decoder__pydoc__template_8h.html#a8446ec118813d5432a119d4530fa52af":[7,0,17,2,0,0,0,18,6],
+"ldpc__decoder__pydoc__template_8h.html#a92864a3a1ee450fe9b2110f948dea459":[7,0,17,2,0,0,0,18,1],
+"ldpc__decoder__pydoc__template_8h.html#aab2f5a2b01eaa874b07d8d22297b2c6c":[7,0,17,2,0,0,0,18,2],
+"ldpc__decoder__pydoc__template_8h.html#ab4a209362046df2a5eaa5d427a5d7dbf":[7,0,17,2,0,0,0,18,9],
+"ldpc__decoder__pydoc__template_8h.html#ac2da51615e247432f5f84807cc4b167a":[7,0,17,2,0,0,0,18,3],
+"ldpc__decoder__pydoc__template_8h.html#ac70bee35ceeee1c87b903007c2064c5d":[7,0,17,2,0,0,0,18,4],
+"ldpc__decoder__pydoc__template_8h.html#ae23244b0f4296fdbdee3061e2db05fed":[7,0,17,2,0,0,0,18,7],
+"ldpc__decoder__pydoc__template_8h_source.html":[7,0,17,2,0,0,0,18],
+"ldpc__encoder_8h.html":[7,0,17,1,0,0,26],
+"ldpc__encoder_8h_source.html":[7,0,17,1,0,0,26],
+"ldpc__encoder__pydoc__template_8h.html":[7,0,17,2,0,0,0,19]
 };
