@@ -1,73 +1,5 @@
 var NAVTREEINDEX77 =
 {
-"time__raster__sink__f__pydoc__template_8h.html#af0c32f274377035d73f901e251d14a26":[7,0,29,2,0,0,0,20,14],
-"time__raster__sink__f__pydoc__template_8h.html#af69b1d759b0df7d5fc7d7266d261da3c":[7,0,29,2,0,0,0,20,18],
-"time__raster__sink__f__pydoc__template_8h.html#af8f0cdbdcbb39972032c6f6d8ddce3eb":[7,0,29,2,0,0,0,20,20],
-"time__raster__sink__f__pydoc__template_8h_source.html":[7,0,29,2,0,0,0,20],
-"time__sink__c_8h.html":[7,0,29,1,0,0,35],
-"time__sink__c_8h_source.html":[7,0,29,1,0,0,35],
-"time__sink__c__pydoc__template_8h.html":[7,0,29,2,0,0,0,21],
-"time__sink__c__pydoc__template_8h.html#a08bc2e2ef05481cd3176e919bcdd8986":[7,0,29,2,0,0,0,21,2],
-"time__sink__c__pydoc__template_8h.html#a14db63879ffe46b3fa446e6920840e74":[7,0,29,2,0,0,0,21,33],
-"time__sink__c__pydoc__template_8h.html#a198ee3079ec2b4e6a6fa528c8d2b6b27":[7,0,29,2,0,0,0,21,16],
-"time__sink__c__pydoc__template_8h.html#a1d53f6d1f48019c29887fd97e928300c":[7,0,29,2,0,0,0,21,9],
-"time__sink__c__pydoc__template_8h.html#a1f45ffa82a7f8c023ba88f32751adbb8":[7,0,29,2,0,0,0,21,23],
-"time__sink__c__pydoc__template_8h.html#a2da6e8c0ad9d1ca96b92c4e7ce50dd36":[7,0,29,2,0,0,0,21,38],
-"time__sink__c__pydoc__template_8h.html#a358cf1238f829a134d97445ed989aad5":[7,0,29,2,0,0,0,21,36],
-"time__sink__c__pydoc__template_8h.html#a3bd0021104854084abcc667d084bef91":[7,0,29,2,0,0,0,21,10],
-"time__sink__c__pydoc__template_8h.html#a56fb7f83b56444a4d6ce50bb2d0e4e20":[7,0,29,2,0,0,0,21,17],
-"time__sink__c__pydoc__template_8h.html#a5b86745903ec417d640cb1a5a9870f21":[7,0,29,2,0,0,0,21,20],
-"time__sink__c__pydoc__template_8h.html#a5fc05b9d65a2d580f67dff0dd1082b13":[7,0,29,2,0,0,0,21,27],
-"time__sink__c__pydoc__template_8h.html#a5ff2842301ff81390e3abf1f1539002b":[7,0,29,2,0,0,0,21,25],
-"time__sink__c__pydoc__template_8h.html#a63c915f560a7c41cbe2a84ccbe094c19":[7,0,29,2,0,0,0,21,40],
-"time__sink__c__pydoc__template_8h.html#a680a8a63ae2377506b56b7fcb3643121":[7,0,29,2,0,0,0,21,22],
-"time__sink__c__pydoc__template_8h.html#a718020bc3f2217b579af6f4a7feded20":[7,0,29,2,0,0,0,21,12],
-"time__sink__c__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,29,2,0,0,0,21,0],
-"time__sink__c__pydoc__template_8h.html#a76c4d9b4d5bfaaf2422f42ea78f33076":[7,0,29,2,0,0,0,21,1],
-"time__sink__c__pydoc__template_8h.html#a776a05470dc318f660afe74754378855":[7,0,29,2,0,0,0,21,11],
-"time__sink__c__pydoc__template_8h.html#a7f613f7723815f5d7aa171fdd2767940":[7,0,29,2,0,0,0,21,5],
-"time__sink__c__pydoc__template_8h.html#a915f7140ebf1f05fc89ce4fecd943c89":[7,0,29,2,0,0,0,21,39],
-"time__sink__c__pydoc__template_8h.html#a93a69f3bd4aa47d276c10b3f433308b1":[7,0,29,2,0,0,0,21,30],
-"time__sink__c__pydoc__template_8h.html#a9a63cf64e6c9964097a67e4cd4a5b197":[7,0,29,2,0,0,0,21,18],
-"time__sink__c__pydoc__template_8h.html#a9ffb5709347001b93519d7159a340c93":[7,0,29,2,0,0,0,21,21],
-"time__sink__c__pydoc__template_8h.html#aa537419bb18fefb352b19028e76b3c63":[7,0,29,2,0,0,0,21,19],
-"time__sink__c__pydoc__template_8h.html#aab19efff836eba5f6b02513f49f32709":[7,0,29,2,0,0,0,21,4],
-"time__sink__c__pydoc__template_8h.html#aac2a4310d14fdd191f28854074e1f1bf":[7,0,29,2,0,0,0,21,6],
-"time__sink__c__pydoc__template_8h.html#aaca557bf51cd1fe35816a076651e63a4":[7,0,29,2,0,0,0,21,34],
-"time__sink__c__pydoc__template_8h.html#ab5d34be541c7d320974ac16875db92c0":[7,0,29,2,0,0,0,21,13],
-"time__sink__c__pydoc__template_8h.html#ab7e8352867a269006e646b1165614e6e":[7,0,29,2,0,0,0,21,8],
-"time__sink__c__pydoc__template_8h.html#aba3a933531eb51d23ad65c59fe90afd0":[7,0,29,2,0,0,0,21,29],
-"time__sink__c__pydoc__template_8h.html#ac67f234f40156db193b295b8ad2518ed":[7,0,29,2,0,0,0,21,24],
-"time__sink__c__pydoc__template_8h.html#ac82ca01b2ad2c62ad4d04c9f2bb91374":[7,0,29,2,0,0,0,21,3],
-"time__sink__c__pydoc__template_8h.html#ac9f805f3a8c3241342e1827693829cc7":[7,0,29,2,0,0,0,21,37],
-"time__sink__c__pydoc__template_8h.html#aca4bb40d81a3bf8621a6e08703dced2a":[7,0,29,2,0,0,0,21,28],
-"time__sink__c__pydoc__template_8h.html#acaa417cc28c34ba1cfe10a21cbc383f7":[7,0,29,2,0,0,0,21,26],
-"time__sink__c__pydoc__template_8h.html#ad495d5abc56a7c68dad1598213602625":[7,0,29,2,0,0,0,21,7],
-"time__sink__c__pydoc__template_8h.html#adea5bfd0632b09b3aaee09931a216ec6":[7,0,29,2,0,0,0,21,35],
-"time__sink__c__pydoc__template_8h.html#ae0253b067dab2136533a6766a6220084":[7,0,29,2,0,0,0,21,14],
-"time__sink__c__pydoc__template_8h.html#ae418613049bc6c6245faaa8ad5f9155e":[7,0,29,2,0,0,0,21,15],
-"time__sink__c__pydoc__template_8h.html#ae63e0b9b8afecfb52f39780a53aee88f":[7,0,29,2,0,0,0,21,32],
-"time__sink__c__pydoc__template_8h.html#af7cec86d06e5fa69a0fc11ea607c2685":[7,0,29,2,0,0,0,21,31],
-"time__sink__c__pydoc__template_8h_source.html":[7,0,29,2,0,0,0,21],
-"time__sink__f_8h.html":[7,0,29,1,0,0,36],
-"time__sink__f_8h_source.html":[7,0,29,1,0,0,36],
-"time__sink__f__pydoc__template_8h.html":[7,0,29,2,0,0,0,22],
-"time__sink__f__pydoc__template_8h.html#a008d9dd1aa16860ed55aaf26eee0fc23":[7,0,29,2,0,0,0,22,26],
-"time__sink__f__pydoc__template_8h.html#a0357f24019adcabd7fd2d9516cf6f8e1":[7,0,29,2,0,0,0,22,27],
-"time__sink__f__pydoc__template_8h.html#a0d610481b31cbeeecfe20f22d3b8b0c0":[7,0,29,2,0,0,0,22,5],
-"time__sink__f__pydoc__template_8h.html#a0e9e2b8126d5a44cfb7e53ced9e1aaec":[7,0,29,2,0,0,0,22,18],
-"time__sink__f__pydoc__template_8h.html#a190dea96930c380a65acef9bede56f44":[7,0,29,2,0,0,0,22,40],
-"time__sink__f__pydoc__template_8h.html#a23eeeee9cac2905babcc1059e8e966c8":[7,0,29,2,0,0,0,22,31],
-"time__sink__f__pydoc__template_8h.html#a31a5cd9b61aa60ff271f1daa4dfcb856":[7,0,29,2,0,0,0,22,34],
-"time__sink__f__pydoc__template_8h.html#a3d8bd7e0361809670307233162f07b17":[7,0,29,2,0,0,0,22,17],
-"time__sink__f__pydoc__template_8h.html#a497b45e625839a58f9516ecce807400c":[7,0,29,2,0,0,0,22,29],
-"time__sink__f__pydoc__template_8h.html#a4e7649c2022e2fe040133a47c0a4abdb":[7,0,29,2,0,0,0,22,20],
-"time__sink__f__pydoc__template_8h.html#a52b1b3e7edb51e5314ab06a460dfede1":[7,0,29,2,0,0,0,22,36],
-"time__sink__f__pydoc__template_8h.html#a587efd48fd444fec22bc92261b517437":[7,0,29,2,0,0,0,22,14],
-"time__sink__f__pydoc__template_8h.html#a5b3b8e82a05c3520c460eec48302347e":[7,0,29,2,0,0,0,22,16],
-"time__sink__f__pydoc__template_8h.html#a5f5efd38ff3e3b8070e5cece6ea152fa":[7,0,29,2,0,0,0,22,30],
-"time__sink__f__pydoc__template_8h.html#a62f5d3da24e0db717d13571098d5da33":[7,0,29,2,0,0,0,22,21],
-"time__sink__f__pydoc__template_8h.html#a652c9d64f6b233e834e5e61d6bf256c5":[7,0,29,2,0,0,0,22,15],
 "time__sink__f__pydoc__template_8h.html#a66b112b842f2897887fa21773cf67c80":[7,0,29,2,0,0,0,22,13],
 "time__sink__f__pydoc__template_8h.html#a695529ac4d73e10b30e8a6cbc8bb81a3":[7,0,29,2,0,0,0,22,11],
 "time__sink__f__pydoc__template_8h.html#a6fd5e93e9985d5046b40ba39f5ec6b3f":[7,0,29,2,0,0,0,22,8],
@@ -249,5 +181,73 @@ var NAVTREEINDEX77 =
 "udp__source__pydoc__template_8h_source.html":[7,0,25,1,0,0,0,4],
 "uhd__types_8h.html":[7,0,34,1,0,0,16],
 "uhd__types_8h_source.html":[7,0,34,1,0,0,16],
-"ulaw__decode__bs_8h.html":[7,0,38,1,0,0,19]
+"ulaw__decode__bs_8h.html":[7,0,38,1,0,0,19],
+"ulaw__decode__bs_8h_source.html":[7,0,38,1,0,0,19],
+"ulaw__decode__bs__pydoc__template_8h.html":[7,0,38,2,0,0,0,17],
+"ulaw__decode__bs__pydoc__template_8h.html#a149112272fdb2508e6de18e5aa45c660":[7,0,38,2,0,0,0,17,2],
+"ulaw__decode__bs__pydoc__template_8h.html#a378304b01d4cbead9b1d49a664575b17":[7,0,38,2,0,0,0,17,3],
+"ulaw__decode__bs__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,38,2,0,0,0,17,0],
+"ulaw__decode__bs__pydoc__template_8h.html#adef71bf24863902abf7b387c03f3a23c":[7,0,38,2,0,0,0,17,1],
+"ulaw__decode__bs__pydoc__template_8h_source.html":[7,0,38,2,0,0,0,17],
+"ulaw__encode__sb_8h.html":[7,0,38,1,0,0,20],
+"ulaw__encode__sb_8h_source.html":[7,0,38,1,0,0,20],
+"ulaw__encode__sb__pydoc__template_8h.html":[7,0,38,2,0,0,0,18],
+"ulaw__encode__sb__pydoc__template_8h.html#a122ff46bce00df6d06dd9e817ca5711c":[7,0,38,2,0,0,0,18,1],
+"ulaw__encode__sb__pydoc__template_8h.html#a19e7d6476df4405c3f3170635cd8458c":[7,0,38,2,0,0,0,18,3],
+"ulaw__encode__sb__pydoc__template_8h.html#a3b08ff5f62288addeb5d86f1c25fdb54":[7,0,38,2,0,0,0,18,2],
+"ulaw__encode__sb__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,38,2,0,0,0,18,0],
+"ulaw__encode__sb__pydoc__template_8h_source.html":[7,0,38,2,0,0,0,18],
+"uniondecision__t.html":[6,0,23],
+"uniondecision__t.html#a606721ca41e795d5a24775bc0771850d":[6,0,23,1],
+"uniondecision__t.html#a99ec0520dcd506cd724096af85f6d7da":[6,0,23,0],
+"uniondecision__t.html#ab081f0f5026819b9b291cb9dda112d1a":[6,0,23,3],
+"uniondecision__t.html#ae3025cf0316023273c5e9517a7001de8":[6,0,23,2],
+"unionmetric__t.html":[6,0,54],
+"unionmetric__t.html#a20cd4db9a1b3e71238df98eb956e0a13":[6,0,54,0],
+"unpack__k__bits_8h.html":[7,0,9,1,0,0,140],
+"unpack__k__bits_8h_source.html":[7,0,9,1,0,0,140],
+"unpack__k__bits__bb_8h.html":[7,0,9,1,0,0,141],
+"unpack__k__bits__bb_8h_source.html":[7,0,9,1,0,0,141],
+"unpack__k__bits__bb__pydoc__template_8h.html":[7,0,9,2,0,0,0,137],
+"unpack__k__bits__bb__pydoc__template_8h.html#a24c334e122cc9dc41e0c433b65e1ee58":[7,0,9,2,0,0,0,137,3],
+"unpack__k__bits__bb__pydoc__template_8h.html#a27a8c2ce92dd58c42592e3159a112768":[7,0,9,2,0,0,0,137,2],
+"unpack__k__bits__bb__pydoc__template_8h.html#a60ae6aa361343c56f5b2ce861d234cc8":[7,0,9,2,0,0,0,137,1],
+"unpack__k__bits__bb__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,9,2,0,0,0,137,0],
+"unpack__k__bits__bb__pydoc__template_8h_source.html":[7,0,9,2,0,0,0,137],
+"unpack__k__bits__pydoc__template_8h.html":[7,0,9,2,0,0,0,138],
+"unpack__k__bits__pydoc__template_8h.html#a09dcbd7c36154229d572d49da0ef12ee":[7,0,9,2,0,0,0,138,4],
+"unpack__k__bits__pydoc__template_8h.html#a1d401459e75069231eaab0a8421077bc":[7,0,9,2,0,0,0,138,3],
+"unpack__k__bits__pydoc__template_8h.html#a2638f9f223dd325c405d08838691feea":[7,0,9,2,0,0,0,138,6],
+"unpack__k__bits__pydoc__template_8h.html#a6450c25e8cef3798045a38e0f02329bf":[7,0,9,2,0,0,0,138,2],
+"unpack__k__bits__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,9,2,0,0,0,138,0],
+"unpack__k__bits__pydoc__template_8h.html#ad2a4e663aba5a84065766adefdb5d07b":[7,0,9,2,0,0,0,138,5],
+"unpack__k__bits__pydoc__template_8h.html#aea554baab7d770c890c294e8f425c143":[7,0,9,2,0,0,0,138,1],
+"unpack__k__bits__pydoc__template_8h_source.html":[7,0,9,2,0,0,0,138],
+"unpacked__to__packed_8h.html":[7,0,9,1,0,0,142],
+"unpacked__to__packed_8h_source.html":[7,0,9,1,0,0,142],
+"unpacked__to__packed__pydoc__template_8h.html":[7,0,9,2,0,0,0,139],
+"unpacked__to__packed__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,9,2,0,0,0,139,0],
+"unpacked__to__packed__pydoc__template_8h_source.html":[7,0,9,2,0,0,0,139],
+"usrp__block_8h.html":[7,0,34,1,0,0,17],
+"usrp__block_8h_source.html":[7,0,34,1,0,0,17],
+"usrp__block__pydoc__template_8h.html":[7,0,34,2,0,0,0,14],
+"usrp__block__pydoc__template_8h.html#a05c924cd5f35b93a721b17901529e62a":[7,0,34,2,0,0,0,14,61],
+"usrp__block__pydoc__template_8h.html#a092833f66acc15f9294826f748d6039e":[7,0,34,2,0,0,0,14,53],
+"usrp__block__pydoc__template_8h.html#a0c572e85188e1227705a7e33bf06e427":[7,0,34,2,0,0,0,14,51],
+"usrp__block__pydoc__template_8h.html#a1c7735d274545df449228be324b9cffa":[7,0,34,2,0,0,0,14,28],
+"usrp__block__pydoc__template_8h.html#a1e9a59317bd4414505ccd4eedbe75c3d":[7,0,34,2,0,0,0,14,36],
+"usrp__block__pydoc__template_8h.html#a20584e3cf7758cbf386bd1f6cfab7f07":[7,0,34,2,0,0,0,14,69],
+"usrp__block__pydoc__template_8h.html#a2189eeb87bc320518d52b91f2a51ad9c":[7,0,34,2,0,0,0,14,25],
+"usrp__block__pydoc__template_8h.html#a23db15adee90fb2448b92db81df4452d":[7,0,34,2,0,0,0,14,1],
+"usrp__block__pydoc__template_8h.html#a30d4c4404dbadac78b6167c6cdc20228":[7,0,34,2,0,0,0,14,31],
+"usrp__block__pydoc__template_8h.html#a3259250e2ba1e9fdc47cb362f7a7ce7a":[7,0,34,2,0,0,0,14,67],
+"usrp__block__pydoc__template_8h.html#a32d48ccd38ea501118992b4cae1aaaea":[7,0,34,2,0,0,0,14,57],
+"usrp__block__pydoc__template_8h.html#a331f5831b76f61ae7e0ae371bb97ea40":[7,0,34,2,0,0,0,14,12],
+"usrp__block__pydoc__template_8h.html#a33ccd0180a51516a3948b8fb2312496e":[7,0,34,2,0,0,0,14,78],
+"usrp__block__pydoc__template_8h.html#a3753a55e7208cd546613b9d55edce01f":[7,0,34,2,0,0,0,14,46],
+"usrp__block__pydoc__template_8h.html#a3990102a818546902244bacc806ec780":[7,0,34,2,0,0,0,14,43],
+"usrp__block__pydoc__template_8h.html#a3b293adf4aeddd2802e7fdfc6d313a50":[7,0,34,2,0,0,0,14,32],
+"usrp__block__pydoc__template_8h.html#a3c79c1ec4f6ee0cad584ae3682e6f4bd":[7,0,34,2,0,0,0,14,50],
+"usrp__block__pydoc__template_8h.html#a42563c1def76d7e5c4e4100a4336a306":[7,0,34,2,0,0,0,14,52],
+"usrp__block__pydoc__template_8h.html#a4904c708968381f02df8c2fa7a74dc59":[7,0,34,2,0,0,0,14,68]
 };
